@@ -1,20 +1,7 @@
 /* Swinder - Portable library for spreadsheet
-   Copyright (C) 2009,2010 Sebastian Sauer <sebsauer@kdab.com>
+   SPDX-FileCopyrightText: 2009, 2010 Sebastian Sauer <sebsauer@kdab.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SWINDER_OBJECTS_H
@@ -22,17 +9,17 @@
 
 #include <Charting.h>
 
+#include "cell.h"
+#include "excel.h"
+#include "format.h"
 #include "formulas.h"
 #include "records.h"
-#include "format.h"
-#include "value.h"
-#include "cell.h"
 #include "sheet.h"
+#include "value.h"
 #include "workbook.h"
-#include "excel.h"
 
-#include <string>
 #include <iostream>
+#include <string>
 #include <vector>
 
 #include <QList>
@@ -41,7 +28,7 @@
 
 namespace MSO
 {
-    class OfficeArtDgContainer;
+class OfficeArtDgContainer;
 }
 
 namespace Swinder
@@ -53,7 +40,6 @@ namespace Swinder
 class Object
 {
 public:
-
     /// The object type.
     enum Type {
         Group = 0x0000,
@@ -84,11 +70,13 @@ public:
     virtual ~Object();
 
     /// Returns the object type.
-    Type type() const {
+    Type type() const
+    {
         return m_type;
     }
     /// Returns the unique object identifier.
-    unsigned long id() const {
+    unsigned long id() const
+    {
         return m_id;
     }
 
@@ -103,23 +91,28 @@ protected:
     unsigned long m_id;
 };
 
-
 /**
  * Note objects used to store comments attached to a cell or revision.
  */
 class NoteObject : public Object
 {
 public:
-    NoteObject(unsigned long id) : Object(Note, id) {}
-    ~NoteObject() override {}
+    NoteObject(unsigned long id)
+        : Object(Note, id)
+    {
+    }
+    ~NoteObject() override = default;
     /// Returns the comment.
-    QString note() const {
+    QString note() const
+    {
         return m_note;
     }
     /// Set the comment.
-    void setNote(const QString &n) {
+    void setNote(const QString &n)
+    {
         m_note = n;
     }
+
 private:
     QString m_note;
 };
@@ -130,16 +123,26 @@ private:
 class ChartObject : public Object
 {
 public:
-    KoChart::Chart* m_chart;
+    std::unique_ptr<KoChart::Chart> m_chart;
 
-    explicit ChartObject(unsigned long id) : Object(Chart, id), m_chart(new KoChart::Chart) {}
-    ~ChartObject() override { delete m_chart; }
-    bool operator==(const ChartObject &other) const { return this == &other; }
-    bool operator!=(const ChartObject &other) const { return ! (*this == other); }
+    explicit ChartObject(unsigned long id)
+        : Object(Chart, id)
+        , m_chart(std::make_unique<KoChart::Chart>())
+    {
+    }
+    ~ChartObject() override = default;
 
-private:
-    ChartObject(const ChartObject& co);
-    ChartObject& operator=(const ChartObject& co);
+    bool operator==(const ChartObject &other) const
+    {
+        return this == &other;
+    }
+    bool operator!=(const ChartObject &other) const
+    {
+        return !(*this == other);
+    }
+
+    ChartObject(const ChartObject &co) = delete;
+    ChartObject &operator=(const ChartObject &co) = delete;
 };
 
 /**
@@ -148,15 +151,22 @@ private:
 class OfficeArtObject
 {
 public:
-    explicit OfficeArtObject(const MSO::OfficeArtSpContainer& object, quint32 index = 0);
+    explicit OfficeArtObject(const MSO::OfficeArtSpContainer &object, quint32 index = 0);
     ~OfficeArtObject();
     MSO::OfficeArtSpContainer object() const;
-    void setText(const TxORecord& text);
+    void setText(const TxORecord &text);
     TxORecord text() const;
     void setIndex(quint32 index);
     quint32 index() const;
-    bool operator==(const OfficeArtObject& other) const { return this == &other; }
-    bool operator!=(const OfficeArtObject& other) const { return !(*this == other); }
+    bool operator==(const OfficeArtObject &other) const
+    {
+        return this == &other;
+    }
+    bool operator!=(const OfficeArtObject &other) const
+    {
+        return !(*this == other);
+    }
+
 private:
     MSO::OfficeArtSpContainer m_object;
     TxORecord m_text;
