@@ -1,23 +1,11 @@
 /*
  * This file is part of Office 2007 Filters for Calligra
  *
- * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2010 Nokia Corporation and /or its subsidiary(-ies).
  *
  * Contact: Suresh Chande suresh.chande@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1-only
  *
  */
 
@@ -26,8 +14,8 @@
 #include "DocxDebug.h"
 
 #include <MsooXmlSchemas.h>
-#include <MsooXmlUtils.h>
 #include <MsooXmlUnits.h>
+#include <MsooXmlUtils.h>
 
 #define MSOOXML_CURRENT_NS "w"
 #define MSOOXML_CURRENT_CLASS MsooXmlNumberingReader
@@ -35,14 +23,11 @@
 
 #include <MsooXmlReader_p.h>
 
-
 class DocxXmlNumberingReader::Private
 {
 public:
-    Private() {
-    }
-    ~Private() {
-    }
+    Private() = default;
+    ~Private() = default;
 };
 
 DocxXmlNumberingReader::DocxXmlNumberingReader(KoOdfWriters *writers)
@@ -63,9 +48,9 @@ void DocxXmlNumberingReader::init()
     m_outputFrames = false;
 }
 
-KoFilter::ConversionStatus DocxXmlNumberingReader::read(MSOOXML::MsooXmlReaderContext* context)
+KoFilter::ConversionStatus DocxXmlNumberingReader::read(MSOOXML::MsooXmlReaderContext *context)
 {
-    m_context = static_cast<DocxXmlDocumentReaderContext*>(context);
+    m_context = static_cast<DocxXmlDocumentReaderContext *>(context);
 
     readNext();
     if (!isStartDocument()) {
@@ -134,7 +119,7 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_abstractNum()
         readNext();
         BREAK_IF_END_OF(CURRENT_EL)
         if (isStartElement()) {
-            if (name() == "lvl") {
+            if (name() == QLatin1StringView("lvl")) {
                 m_currentBulletProperties.clear();
                 TRY_READ(lvl)
                 m_currentBulletList.append(m_currentBulletProperties);
@@ -175,7 +160,7 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_lvlOverride()
         readNext();
         BREAK_IF_END_OF(CURRENT_EL)
         if (isStartElement()) {
-            if (name() == "lvl") {
+            if (name() == QLatin1StringView("lvl")) {
                 m_currentBulletProperties.clear();
                 TRY_READ(lvl)
                 int index = 0;
@@ -187,14 +172,12 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_lvlOverride()
                     }
                     ++index;
                 }
-            }
-            else if (name() == "startOverride") {
+            } else if (name() == QLatin1StringView("startOverride")) {
                 int index = 0;
                 while (index < m_currentBulletList.size()) {
-                    if (m_currentBulletList.at(index).m_level == level)
-                    {
+                    if (m_currentBulletList.at(index).m_level == level) {
                         const QXmlStreamAttributes attrs2(attributes());
-                        QString val( attrs2.value(QUALIFIED_NAME(val)).toString() );
+                        QString val(attrs2.value(QUALIFIED_NAME(val)).toString());
                         if (!val.isEmpty()) {
                             m_currentBulletList[index].setStartValue(val);
                         }
@@ -261,17 +244,16 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_lvl()
             ELSE_TRY_READ_IF(lvlText)
             ELSE_TRY_READ_IF(lvlJc)
             ELSE_TRY_READ_IF(suff)
-            else if (name() == "lvlPicBulletId") {
+            else if (name() == QLatin1StringView("lvlPicBulletId"))
+            {
                 TRY_READ(lvlPicBulletId)
                 pictureType = true;
             }
-            else if (name() == "pPr") {
+            else if (name() == QLatin1StringView("pPr"))
+            {
                 TRY_READ(pPr_numbering)
             }
-            else if (name() == "rPr") {
-                TRY_READ(rPr)
-            }
-            SKIP_UNKNOWN
+            else if (name() == QLatin1StringView("rPr")){TRY_READ(rPr)} SKIP_UNKNOWN
         }
     }
 
@@ -362,23 +344,17 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_numFmt()
     if (!val.isEmpty()) {
         if (val == "lowerRoman") {
             m_currentBulletProperties.setNumFormat("i");
-        }
-        else if (val == "lowerLetter") {
+        } else if (val == "lowerLetter") {
             m_currentBulletProperties.setNumFormat("a");
-        }
-        else if (val == "decimal") {
+        } else if (val == "decimal") {
             m_currentBulletProperties.setNumFormat("1");
-        }
-        else if (val == "upperRoman") {
+        } else if (val == "upperRoman") {
             m_currentBulletProperties.setNumFormat("I");
-        }
-        else if (val == "upperLetter") {
+        } else if (val == "upperLetter") {
             m_currentBulletProperties.setNumFormat("A");
-        }
-        else if (val == "bullet") {
+        } else if (val == "bullet") {
             m_bulletStyle = true;
-        }
-        else if (val == "ordinal") {
+        } else if (val == "ordinal") {
             // in ooxml this means having 1st, 2nd etc. but currently there's no real support for it
             m_currentBulletProperties.setNumFormat("1");
             m_currentBulletProperties.setSuffix(".");
@@ -435,12 +411,10 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_lvlText()
         if (!m_bulletStyle) {
             if (val.at(0) == '%' && val.length() == 2) {
                 m_currentBulletProperties.setSuffix("");
-            }
-            else {
+            } else {
                 m_currentBulletProperties.setSuffix(val.right(1));
             }
-        }
-        else {
+        } else {
             m_bulletCharacter = val;
         }
     }
@@ -475,10 +449,10 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_num()
         readNext();
         BREAK_IF_END_OF(CURRENT_EL)
         if (isStartElement()) {
-            if (name() == "abstractNumId") {
-               TRY_READ(abstractNumId)
-               m_currentBulletList = m_abstractListStyles[m_currentAbstractId];
-               m_context->m_abstractNumIDs[numId] = m_currentAbstractId;
+            if (name() == QLatin1StringView("abstractNumId")) {
+                TRY_READ(abstractNumId)
+                m_currentBulletList = m_abstractListStyles[m_currentAbstractId];
+                m_context->m_abstractNumIDs[numId] = m_currentAbstractId;
             }
             // lvlOverride may modify the bulletlist which we get above
             ELSE_TRY_READ_IF(lvlOverride)
@@ -553,7 +527,7 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_pPr_numbering()
             if (qualifiedName() == QLatin1String("w:ind")) {
                 TRY_READ(ind_numbering)
             }
-            //TODO: tabs are important
+            // TODO: tabs are important
             SKIP_UNKNOWN
         }
     }
@@ -692,13 +666,12 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_ind_numbering()
     if (!hanging.isEmpty()) {
         const qreal firstInd = qreal(TWIP_TO_POINT(hanging.toDouble(&ok)));
         if (ok) {
-           m_currentBulletProperties.setIndent(-firstInd);
+            m_currentBulletProperties.setIndent(-firstInd);
         }
-    }
-    else if (!firstLine.isEmpty()) {
+    } else if (!firstLine.isEmpty()) {
         const qreal firstInd = qreal(TWIP_TO_POINT(firstLine.toDouble(&ok)));
         if (ok) {
-           m_currentBulletProperties.setIndent(firstInd);
+            m_currentBulletProperties.setIndent(firstInd);
         }
     }
 
@@ -830,4 +803,3 @@ KoFilter::ConversionStatus DocxXmlNumberingReader::read_ind_numbering()
 //     readNext();
 //     READ_EPILOGUE
 // }
-
