@@ -1,38 +1,25 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008-2010 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008-2010 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOCREATEPATHTOOL_P_H
 #define KOCREATEPATHTOOL_P_H
 
+#include "KoCanvasBase.h"
 #include "KoCreatePathTool.h"
-#include "KoStrokeConfigWidget.h"
+#include "KoParameterShape.h"
 #include "KoPathPoint.h"
 #include "KoPathPointData.h"
 #include "KoPathPointMergeCommand.h"
-#include "KoCanvasBase.h"
-#include "KoParameterShape.h"
-#include "KoViewConverter.h"
 #include "KoShapeManager.h"
 #include "KoSnapStrategy.h"
+#include "KoStrokeConfigWidget.h"
 #include "KoToolBase_p.h"
+#include "KoViewConverter.h"
 
 #include <QPainterPath>
 
@@ -41,20 +28,21 @@
 /// Small helper to keep track of a path point and its parent path shape
 struct PathConnectionPoint {
     PathConnectionPoint()
-    : path(0), point(0)
+        : path(nullptr)
+        , point(nullptr)
     {
     }
 
     // reset state to invalid
     void reset()
     {
-        path = 0;
-        point = 0;
+        path = nullptr;
+        point = nullptr;
     }
 
-    PathConnectionPoint& operator =(KoPathPoint * pathPoint)
+    PathConnectionPoint &operator=(KoPathPoint *pathPoint)
     {
-        if (!pathPoint || ! pathPoint->parent()) {
+        if (!pathPoint || !pathPoint->parent()) {
             reset();
         } else {
             path = pathPoint->parent();
@@ -63,12 +51,12 @@ struct PathConnectionPoint {
         return *this;
     }
 
-    bool operator != (const PathConnectionPoint &rhs) const
+    bool operator!=(const PathConnectionPoint &rhs) const
     {
         return rhs.path != path || rhs.point != point;
     }
 
-    bool operator == (const PathConnectionPoint &rhs) const
+    bool operator==(const PathConnectionPoint &rhs) const
     {
         return rhs.path == path && rhs.point == point;
     }
@@ -96,28 +84,30 @@ struct PathConnectionPoint {
             return;
         }
         // check if point is still part of the path
-        if (path->pathPointIndex(point) == KoPathPointIndex(-1,-1)) {
+        if (path->pathPointIndex(point) == KoPathPointIndex(-1, -1)) {
             reset();
             return;
         }
     }
 
-    KoPathShape * path;
-    KoPathPoint * point;
+    KoPathShape *path;
+    KoPathPoint *point;
 };
 
-inline qreal squareDistance( const QPointF &p1, const QPointF &p2)
+inline qreal squareDistance(const QPointF &p1, const QPointF &p2)
 {
-    qreal dx = p1.x()-p2.x();
-    qreal dy = p1.y()-p2.y();
-    return dx*dx + dy*dy;
+    qreal dx = p1.x() - p2.x();
+    qreal dy = p1.y() - p2.y();
+    return dx * dx + dy * dy;
 }
 
 class AngleSnapStrategy : public KoSnapStrategy
 {
 public:
-    explicit AngleSnapStrategy( qreal angleStep, bool active)
-    : KoSnapStrategy(KoSnapGuide::CustomSnapping), m_angleStep(angleStep), m_active(active)
+    explicit AngleSnapStrategy(qreal angleStep, bool active)
+        : KoSnapStrategy(KoSnapGuide::CustomSnapping)
+        , m_angleStep(angleStep)
+        , m_active(active)
     {
     }
 
@@ -131,7 +121,7 @@ public:
         m_angleStep = qAbs(angleStep);
     }
 
-    bool snap(const QPointF &mousePosition, KoSnapProxy * proxy, qreal maxSnapDistance) override
+    bool snap(const QPointF &mousePosition, KoSnapProxy *proxy, qreal maxSnapDistance) override
     {
         Q_UNUSED(proxy);
 
@@ -142,8 +132,8 @@ public:
         qreal currentAngle = line.angle();
         int prevStep = qAbs(currentAngle / m_angleStep);
         int nextStep = prevStep + 1;
-        qreal prevAngle = prevStep*m_angleStep;
-        qreal nextAngle = nextStep*m_angleStep;
+        qreal prevAngle = prevStep * m_angleStep;
+        qreal nextAngle = nextStep * m_angleStep;
 
         if (qAbs(currentAngle - prevAngle) <= qAbs(currentAngle - nextAngle)) {
             line.setAngle(prevAngle);
@@ -151,7 +141,7 @@ public:
             line.setAngle(nextAngle);
         }
 
-        qreal maxSquareSnapDistance = maxSnapDistance*maxSnapDistance;
+        qreal maxSquareSnapDistance = maxSnapDistance * maxSnapDistance;
         qreal snapDistance = squareDistance(mousePosition, line.p2());
         if (snapDistance > maxSquareSnapDistance)
             return false;
@@ -175,7 +165,8 @@ public:
         m_active = false;
     }
 
-    void activate(){
+    void activate()
+    {
         m_active = true;
     }
 
@@ -185,27 +176,29 @@ private:
     bool m_active;
 };
 
+class KoCreatePathToolPrivate : public KoToolBasePrivate
+{
+    KoCreatePathTool *const q;
 
-class KoCreatePathToolPrivate : public KoToolBasePrivate {
-    KoCreatePathTool * const q;
 public:
-    KoCreatePathToolPrivate(KoCreatePathTool * const qq, KoCanvasBase* canvas)
-        : KoToolBasePrivate(qq, canvas),
-        q(qq),
-        shape(0),
-        activePoint(0),
-        firstPoint(0),
-        handleRadius(3),
-        mouseOverFirstPoint(false),
-        pointIsDragged(false),
-        finishAfterThisPoint(false),
-        hoveredPoint(0),
-        listeningToModifiers(false),
-        angleSnapStrategy(0),
-        angleSnappingDelta(15),
-        angleSnapStatus(false),
-        strokeWidget(0)
-    {}
+    KoCreatePathToolPrivate(KoCreatePathTool *const qq, KoCanvasBase *canvas)
+        : KoToolBasePrivate(qq, canvas)
+        , q(qq)
+        , shape(nullptr)
+        , activePoint(nullptr)
+        , firstPoint(nullptr)
+        , handleRadius(3)
+        , mouseOverFirstPoint(false)
+        , pointIsDragged(false)
+        , finishAfterThisPoint(false)
+        , hoveredPoint(nullptr)
+        , listeningToModifiers(false)
+        , angleSnapStrategy(nullptr)
+        , angleSnappingDelta(15)
+        , angleSnapStatus(false)
+        , strokeWidget(nullptr)
+    {
+    }
 
     KoPathShape *shape;
     KoPathPoint *activePoint;
@@ -215,7 +208,7 @@ public:
     bool pointIsDragged;
     bool finishAfterThisPoint;
     PathConnectionPoint existingStartPoint; ///< an existing path point we started a new path at
-    PathConnectionPoint existingEndPoint;   ///< an existing path point we finished a new path at
+    PathConnectionPoint existingEndPoint; ///< an existing path point we finished a new path at
     KoPathPoint *hoveredPoint; ///< an existing path end point the mouse is hovering on
     bool listeningToModifiers; //  Fine tune when to begin processing modifiers at the beginning of a stroke.
 
@@ -248,33 +241,32 @@ public:
             rect = rect.united(QRectF(point, controlPoint).normalized());
         }
 
-        QPointF border = q->canvas()->viewConverter()
-                         ->viewToDocument(QPointF(handleRadius, handleRadius));
+        QPointF border = q->canvas()->viewConverter()->viewToDocument(QPointF(handleRadius, handleRadius));
 
         rect.adjust(-border.x(), -border.y(), border.x(), border.y());
         q->canvas()->updateCanvas(rect);
     }
 
     /// returns the nearest existing path point
-    KoPathPoint* endPointAtPosition( const QPointF &position ) const
+    KoPathPoint *endPointAtPosition(const QPointF &position) const
     {
         QRectF roi = q->handleGrabRect(position);
         QList<KoShape *> shapes = q->canvas()->shapeManager()->shapesAt(roi);
 
-        KoPathPoint * nearestPoint = 0;
+        KoPathPoint *nearestPoint = nullptr;
         qreal minDistance = HUGE_VAL;
         uint grabSensitivity = q->grabSensitivity();
         qreal maxDistance = q->canvas()->viewConverter()->viewToDocumentX(grabSensitivity);
 
-        foreach(KoShape *s, shapes) {
-            KoPathShape * path = dynamic_cast<KoPathShape*>(s);
+        foreach (KoShape *s, shapes) {
+            KoPathShape *path = dynamic_cast<KoPathShape *>(s);
             if (!path)
                 continue;
-            KoParameterShape *paramShape = dynamic_cast<KoParameterShape*>(s);
+            KoParameterShape *paramShape = dynamic_cast<KoParameterShape *>(s);
             if (paramShape && paramShape->isParametricShape())
                 continue;
 
-            KoPathPoint * p = 0;
+            KoPathPoint *p = nullptr;
             uint subpathCount = path->subpathCount();
             for (uint i = 0; i < subpathCount; ++i) {
                 if (path->isClosedSubpath(i))
@@ -287,7 +279,7 @@ public:
                     minDistance = d;
                 }
                 // check end of subpath
-                p = path->pointByIndex(KoPathPointIndex(i, path->subpathPointCount(i)-1));
+                p = path->pointByIndex(KoPathPointIndex(i, path->subpathPointCount(i) - 1));
                 d = squareDistance(position, path->shapeToDocument(p->point()));
                 if (d < minDistance && d < maxDistance) {
                     nearestPoint = p;
@@ -300,12 +292,12 @@ public:
     }
 
     /// Connects given path with the ones we hit when starting/finishing
-    bool connectPaths( KoPathShape *pathShape, const PathConnectionPoint &pointAtStart, const PathConnectionPoint &pointAtEnd ) const
+    bool connectPaths(KoPathShape *pathShape, const PathConnectionPoint &pointAtStart, const PathConnectionPoint &pointAtEnd) const
     {
-        KoPathShape * startShape = 0;
-        KoPathShape * endShape = 0;
-        KoPathPoint * startPoint = 0;
-        KoPathPoint * endPoint = 0;
+        KoPathShape *startShape = nullptr;
+        KoPathShape *endShape = nullptr;
+        KoPathPoint *startPoint = nullptr;
+        KoPathPoint *endPoint = nullptr;
 
         if (pointAtStart.isValid()) {
             startShape = pointAtStart.path;
@@ -321,7 +313,7 @@ public:
             return false;
         // do not allow connecting to the same point twice
         if (startPoint == endPoint)
-            endPoint = 0;
+            endPoint = nullptr;
 
         // we have hit an existing path point on start/finish
         // what we now do is:
@@ -330,19 +322,19 @@ public:
 
         uint newPointCount = pathShape->subpathPointCount(0);
         KoPathPointIndex newStartPointIndex(0, 0);
-        KoPathPointIndex newEndPointIndex(0, newPointCount-1);
-        KoPathPoint * newStartPoint = pathShape->pointByIndex(newStartPointIndex);
-        KoPathPoint * newEndPoint = pathShape->pointByIndex(newEndPointIndex);
+        KoPathPointIndex newEndPointIndex(0, newPointCount - 1);
+        KoPathPoint *newStartPoint = pathShape->pointByIndex(newStartPointIndex);
+        KoPathPoint *newEndPoint = pathShape->pointByIndex(newEndPointIndex);
 
         // combine with the path we hit on start
-        KoPathPointIndex startIndex(-1,-1);
+        KoPathPointIndex startIndex(-1, -1);
         if (startShape && startPoint) {
             startIndex = startShape->pathPointIndex(startPoint);
             pathShape->combine(startShape);
-            pathShape->moveSubpath(0, pathShape->subpathCount()-1);
+            pathShape->moveSubpath(0, pathShape->subpathCount() - 1);
         }
         // combine with the path we hit on finish
-        KoPathPointIndex endIndex(-1,-1);
+        KoPathPointIndex endIndex(-1, -1);
         if (endShape && endPoint) {
             endIndex = endShape->pathPointIndex(endPoint);
             if (endShape != startShape) {
@@ -355,7 +347,7 @@ public:
 
         if (startIndex.second == 0 && !connectToSingleSubpath) {
             pathShape->reverseSubpath(startIndex.first);
-            startIndex.second = pathShape->subpathPointCount(startIndex.first)-1;
+            startIndex.second = pathShape->subpathPointCount(startIndex.first) - 1;
         }
         if (endIndex.second > 0 && !connectToSingleSubpath) {
             pathShape->reverseSubpath(endIndex.first);
@@ -370,8 +362,8 @@ public:
 
         // get the path points we want to merge, as these are not going to
         // change while merging
-        KoPathPoint * existingStartPoint = pathShape->pointByIndex(startIndex);
-        KoPathPoint * existingEndPoint = pathShape->pointByIndex(endIndex);
+        KoPathPoint *existingStartPoint = pathShape->pointByIndex(startIndex);
+        KoPathPoint *existingEndPoint = pathShape->pointByIndex(endIndex);
 
         // merge first two points
         if (existingStartPoint) {
@@ -393,7 +385,8 @@ public:
 
     void addPathShape()
     {
-        if (!shape) return;
+        if (!shape)
+            return;
 
         if (shape->pointCount() < 2) {
             cleanUp();
@@ -402,7 +395,7 @@ public:
 
         // this is done so that nothing happens when the mouseReleaseEvent for the this event is received
         KoPathShape *pathShape = shape;
-        shape=0;
+        shape = nullptr;
 
         q->addPathShape(pathShape);
 
@@ -411,17 +404,18 @@ public:
         return;
     }
 
-    void cleanUp() {
+    void cleanUp()
+    {
         // reset snap guide
         q->canvas()->updateCanvas(q->canvas()->snapGuide()->boundingRect());
         q->canvas()->snapGuide()->reset();
-        angleSnapStrategy = 0;
+        angleSnapStrategy = nullptr;
 
         delete shape;
-        shape=0;
-        existingStartPoint = 0;
-        existingEndPoint = 0;
-        hoveredPoint = 0;
+        shape = nullptr;
+        existingStartPoint = nullptr;
+        existingEndPoint = nullptr;
+        hoveredPoint = nullptr;
         listeningToModifiers = false;
     }
 
@@ -432,11 +426,11 @@ public:
             angleSnapStrategy->setAngleStep(angleSnappingDelta);
     }
 
-    void angleSnapChanged(int angleSnap){
-        angleSnapStatus = ! angleSnapStatus;
-        if(angleSnapStrategy)
-        {
-            if(angleSnap == Qt::Checked)
+    void angleSnapChanged(int angleSnap)
+    {
+        angleSnapStatus = !angleSnapStatus;
+        if (angleSnapStrategy) {
+            if (angleSnap == Qt::Checked)
                 angleSnapStrategy->activate();
             else
                 angleSnapStrategy->deactivate();
