@@ -1,24 +1,11 @@
 /*
 * This file is part of the KDE project
 *
-* Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* SPDX-FileCopyrightText: 2009 Nokia Corporation and /or its subsidiary(-ies).
 *
 * Contact: Amit Aggarwal <amitcs06@gmail.com>
 *
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Lesser General Public
-* License as published by the Free Software Foundation; either
-* version 2.1 of the License, or (at your option) any later version.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this library; if not, write to the Free Software
-* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA
+SPDX-License-Identifier: LGPL-2.1-or-later
 *
 */
 
@@ -28,7 +15,7 @@
 #include <KoProperties.h>
 #include <KoXmlNS.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 PresentationVariableFactory::PresentationVariableFactory()
     : KoInlineObjectFactoryBase("PresentationVariable", Other)
@@ -50,7 +37,9 @@ PresentationVariableFactory::PresentationVariableFactory()
     addTemplate(var2);
 
     QStringList elementNames;
-    elementNames << "footer" << "header" << "date-time";
+    elementNames << "footer"
+                 << "header"
+                 << "date-time";
     setOdfElementNames(KoXmlNS::presentation, elementNames);
 }
 
@@ -61,4 +50,3 @@ KoInlineObject *PresentationVariableFactory::createInlineObject(const KoProperti
         var->setProperties(properties);
     return var;
 }
-
