@@ -1,29 +1,16 @@
 /* This file is part of the Calligra project
- * Copyright (C) 2005, 2007-2008, 2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Pierre Ducroquet <pinaraf@pinaraf.info>
- * Copyright (C) 2005, 2007-2008, 2011 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2005, 2007-2008, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Pierre Ducroquet <pinaraf@pinaraf.info>
+ * SPDX-FileCopyrightText: 2005, 2007-2008, 2011 Sebastian Sauer <mail@dipe.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KWPage.h"
 #include "KWPageManager_p.h"
+#include <KoShape.h>
 #include <KoShapeManager.h>
 #include <KoZoomHandler.h>
-#include <KoShape.h>
 #include <QPainter>
 
 #include <WordsDebug.h>
@@ -41,28 +28,28 @@ bool KWPage::isValid() const
 
 int KWPage::pageNumber() const
 {
-    if (! isValid())
+    if (!isValid())
         return -1; // invalid
     return priv->pages[n].pageNumber;
 }
 
 KWPageStyle KWPage::pageStyle() const
 {
-    if (! isValid())
+    if (!isValid())
         return KWPageStyle(); // invalid
 
     return priv->pages[n].style;
 }
 
-void KWPage::setPageStyle(const KWPageStyle style)
+void KWPage::setPageStyle(const KWPageStyle &style)
 {
-    if (! isValid())
+    if (!isValid())
         return;
-    if (! style.isValid()) {
+    if (!style.isValid()) {
         warnWords << "Passing invalid style to KWPage::setPageStyle()";
         return;
     }
-    if (! priv->pageStyles.contains(style.name()))
+    if (!priv->pageStyles.contains(style.name()))
         priv->pageStyles.insert(style.name(), style);
 
     KWPageManagerPrivate::Page page = priv->pages[n];
@@ -72,7 +59,7 @@ void KWPage::setPageStyle(const KWPageStyle style)
 
 void KWPage::setPageSide(PageSide ps)
 {
-    if (! isValid())
+    if (!isValid())
         return;
     KWPageManagerPrivate::Page page = priv->pages[n];
 
@@ -85,7 +72,7 @@ void KWPage::setPageSide(PageSide ps)
 
 KWPage::PageSide KWPage::pageSide() const
 {
-    if (! isValid())
+    if (!isValid())
         return KWPage::Left; // invalid
 
     return priv->pages[n].pageSide;
@@ -103,7 +90,7 @@ uint KWPage::hash() const
 
 qreal KWPage::width() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().width;
@@ -111,7 +98,7 @@ qreal KWPage::width() const
 
 qreal KWPage::height() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().height;
@@ -119,7 +106,7 @@ qreal KWPage::height() const
 
 qreal KWPage::topMargin() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().topMargin;
@@ -127,7 +114,7 @@ qreal KWPage::topMargin() const
 
 qreal KWPage::bottomMargin() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().bottomMargin;
@@ -135,7 +122,7 @@ qreal KWPage::bottomMargin() const
 
 qreal KWPage::leftMargin() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     qreal answer = page.pageSide == Left ? pageEdgeMargin() : marginClosestBinding();
@@ -146,7 +133,7 @@ qreal KWPage::leftMargin() const
 
 qreal KWPage::rightMargin() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     qreal answer = page.pageSide == Right ? pageEdgeMargin() : marginClosestBinding();
@@ -157,7 +144,7 @@ qreal KWPage::rightMargin() const
 
 qreal KWPage::topPadding() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().topPadding;
@@ -165,7 +152,7 @@ qreal KWPage::topPadding() const
 
 qreal KWPage::bottomPadding() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().bottomPadding;
@@ -173,7 +160,7 @@ qreal KWPage::bottomPadding() const
 
 qreal KWPage::leftPadding() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().leftPadding;
@@ -181,7 +168,7 @@ qreal KWPage::leftPadding() const
 
 qreal KWPage::rightPadding() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().rightPadding;
@@ -189,7 +176,7 @@ qreal KWPage::rightPadding() const
 
 qreal KWPage::pageEdgeMargin() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().pageEdge;
@@ -197,7 +184,7 @@ qreal KWPage::pageEdgeMargin() const
 
 qreal KWPage::marginClosestBinding() const
 {
-    if (! isValid())
+    if (!isValid())
         return 0;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.style.pageLayout().bindingSide;
@@ -216,14 +203,14 @@ void KWPage::setOffsetInDocument(qreal offset)
 
 QRectF KWPage::rect() const
 {
-    if (! isValid())
+    if (!isValid())
         return QRectF();
     return QRectF(0, offsetInDocument(), width(), height());
 }
 
 QRectF KWPage::contentRect() const
 {
-    if (! isValid())
+    if (!isValid())
         return QRectF();
     return priv->pages[n].contentRect;
 }
@@ -237,7 +224,7 @@ void KWPage::setContentRect(const QRectF &rect)
 
 KoPageFormat::Orientation KWPage::orientationHint() const
 {
-    if (! isValid())
+    if (!isValid())
         return KoPageFormat::Landscape;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     return page.orientation;
@@ -245,7 +232,7 @@ KoPageFormat::Orientation KWPage::orientationHint() const
 
 void KWPage::setOrientationHint(KoPageFormat::Orientation orientation)
 {
-    if (! isValid())
+    if (!isValid())
         return;
     KWPageManagerPrivate::Page page = priv->pages[n];
     page.orientation = orientation;
@@ -254,9 +241,9 @@ void KWPage::setOrientationHint(KoPageFormat::Orientation orientation)
 
 const KWPage KWPage::previous() const
 {
-    if (! isValid())
+    if (!isValid())
         return KWPage();
-    QMap<int,int>::const_iterator iter = priv->pageNumbers.constFind(pageNumber());
+    QMap<int, int>::const_iterator iter = priv->pageNumbers.constFind(pageNumber());
     if (iter == priv->pageNumbers.constBegin())
         return KWPage();
     --iter;
@@ -265,9 +252,9 @@ const KWPage KWPage::previous() const
 
 const KWPage KWPage::next() const
 {
-    if (! isValid())
+    if (!isValid())
         return KWPage();
-    QMap<int,int>::const_iterator iter = priv->pageNumbers.constFind(pageNumber());
+    QMap<int, int>::const_iterator iter = priv->pageNumbers.constFind(pageNumber());
     Q_ASSERT(iter != priv->pageNumbers.constEnd());
     ++iter;
     if (iter == priv->pageNumbers.constEnd())
@@ -286,7 +273,7 @@ void KWPage::setDirectionHint(KoText::Direction direction)
 
 KoText::Direction KWPage::directionHint() const
 {
-    if (! isValid())
+    if (!isValid())
         return KoText::AutoDirection;
     const KWPageManagerPrivate::Page &page = priv->pages[n];
     KoText::Direction dir = page.textDirection;
@@ -312,7 +299,6 @@ bool KWPage::isAutoGenerated() const
     return page.autoGenerated;
 }
 
-
 QImage KWPage::thumbnail(const QSize &size, KoShapeManager *shapeManager, bool asPrint) const
 {
     KoZoomHandler zoomHandler;
@@ -326,16 +312,16 @@ QImage KWPage::thumbnail(const QSize &size, KoShapeManager *shapeManager, bool a
     // adapt thumbnailSize to match the rendered page
     QSize thumbnailSize(size);
     if (widthScale > heightScale) {
-        const int thumbnailWidth = qMin(thumbnailSize.width(), qRound(realWidth*heightScale));
+        const int thumbnailWidth = qMin(thumbnailSize.width(), qRound(realWidth * heightScale));
         thumbnailSize.setWidth(thumbnailWidth);
     } else {
-        const int thumbnailHeight = qMin(thumbnailSize.height(), qRound(realHeight*widthScale));
+        const int thumbnailHeight = qMin(thumbnailSize.height(), qRound(realHeight * widthScale));
         thumbnailSize.setHeight(thumbnailHeight);
     }
 
     zoomHandler.setZoom(zoom);
 
-    foreach(KoShape* shape, shapeManager->shapes()) {
+    foreach (KoShape *shape, shapeManager->shapes()) {
         shape->waitUntilReady(zoomHandler, false);
     }
 
@@ -354,9 +340,10 @@ QImage KWPage::thumbnail(const QSize &size, KoShapeManager *shapeManager, bool a
 
 int KWPage::visiblePageNumber(PageSelection select, int adjustment) const
 {
-    KWPage page = *(const_cast<KWPage*>(this));
+    KWPage page = *(const_cast<KWPage *>(this));
     switch (select) {
-    case KoTextPage::CurrentPage: break;
+    case KoTextPage::CurrentPage:
+        break;
     case KoTextPage::PreviousPage:
         page = page.previous();
         break;
@@ -365,7 +352,7 @@ int KWPage::visiblePageNumber(PageSelection select, int adjustment) const
         break;
     }
 
-    if (! page.isValid())
+    if (!page.isValid())
         return -1;
 
     int pageNumber = 0;
